<?php

if (!defined('DS')) {
    define('DS', DIRECTORY_SEPARATOR);
}

require_once dirname(__FILE__) . DS . 'class.HostwindsReseller_default_Product.php';
require_once dirname(__FILE__) . DS . 'class.HostwindsReseller_default_ResellerProduct.php';
require_once dirname(__FILE__) . DS . 'class.HostwindsReseller_default_Hosting.php';
require_once dirname(__FILE__) . DS . 'class.ApiResponse.php';
require_once dirname(__FILE__) . DS . 'modules' . DS . 'class.module.php';
require_once dirname(__FILE__) . DS . 'functions.php';

function HostwindsReseller_default_MetaData()
{
    return [
        'DisplayName' => 'HostwindsReseller_Service',
    ];
}


function HostwindsReseller_default_ConfigOptions($loadValuesFromServer = true)
{
    $ex = explode(DS, $_SERVER['SCRIPT_FILENAME']);
    if ($loadValuesFromServer && end($ex) == 'configproducts.php' && isset($_REQUEST['id']) && $_REQUEST['id']) {

        $removeErrorFieldLabelScript = '<script type="text/javascript">
			$(document).ready(function(){
                                $(".errorbox").closest("td").prev().remove();				
			});
			</script>';

        HostwindsReseller_default_Product::setupDbTable();
        // setup params
        $product = new HostwindsReseller_default_ResellerProduct($_REQUEST['id']);
        $params = $product->getParams();

        if (empty($params)) {
            $error = '<div class="errorbox"><strong><span class="title">Please setup API details first</span></strong></div>';

            return [
                'Content' => [
                    'Description' => $error . $removeErrorFieldLabelScript,
                ],
            ];
        }

        $product->generateDefaultCustomField();

        // @dynamicsubmodules
        //$modules = HostwindsReseller_default_module::getAllModules();
        //foreach ($modules as $module)
        //	$product->defaultConfig['submodule']['options'][$module] = $module;

        // products
        try {
            $module = HostwindsReseller_default_module::getModule($product);
            $module->params = $params;

            $response = $module->getProductsFromSeller();
            if (!$response->isSuccess()) {
                $error = '<div class="errorbox"><strong><span class="title">Unable to get product list - ' . $response->getMessage() . '</span></strong></div>';

                return [
                    'Content' => [
                        'Description' => $error . $removeErrorFieldLabelScript,
                    ],
                ];
            }
            foreach ($response->json['products'] as $groupName => $prs) {
                foreach ($prs as $p) {
                    $product->defaultConfig['target_product']['options'][$groupName][$p['id']] = $p['name'];
                }
            }
        } catch (Exception $e) {
            $error = '<div class="errorbox"><strong><span class="title">Error: ' . $e->getMessage() . '</span></strong></div>';

            return [
                'Content' => [
                    'Description' => $error . $removeErrorFieldLabelScript,
                ],
            ];
        }

        $content = $product->renderConfigOptions('
			<script type="text/javascript">
			$(document).ready(function(){
                                $(".configoption_group").closest("tr").prev().remove();				
			});
			</script>
		');

        return [
            'Content' => [
                'Description' => $content,
            ],
        ];
    }
}

function HostwindsReseller_default_CreateAccount($params)
{
    $product = new HostwindsReseller_default_ResellerProduct($params['pid']);
    $product->generateDefaultCustomField();
    return HostwindsReseller_default_SimpleModuleCall('CreateAccount', $params);
}

function HostwindsReseller_default_TerminateAccount($params)
{
    return HostwindsReseller_default_SimpleModuleCall('TerminateAccount', $params);
}

function HostwindsReseller_default_SuspendAccount($params)
{
    return HostwindsReseller_default_SimpleModuleCall('SuspendAccount', $params);
}

function HostwindsReseller_default_UnsuspendAccount($params)
{
    return HostwindsReseller_default_SimpleModuleCall('UnsuspendAccount', $params);
}

function HostwindsReseller_default_ChangePassword($params)
{
    return HostwindsReseller_default_SimpleModuleCall('ChangePassword', $params);
}

function HostwindsReseller_default_ChangePackage($params)
{
    return HostwindsReseller_default_SimpleModuleCall('ChangePackage', $params);
}


function HostwindsReseller_default_ClientArea($params)
{
    global $smarty;

    try {
        $module = HostwindsReseller_default_module::getModule($params['pid']);
        $module->params = $params;
        $module->hosting = new HostwindsReseller_default_Hosting($params['serviceid']);
        $vars = $module->clientarea($params);
        $vars['_LANG'] = $module->getLang();
        foreach ($vars as $k => $v) {
            $smarty->assign($k, $v);
        }

        $submodule = substr(get_class($module), strlen('HostwindsReseller_default_'));
        $additionalFunctionsPath = dirname(__FILE__) . DS . 'modules' . DS . $submodule . DS . 'functions.php';
        if (file_exists($additionalFunctionsPath)) {
            include_once $additionalFunctionsPath;
        }

        return [
            'tabOverviewReplacementTemplate' => 'modules' . DS . $submodule . DS . 'templates' . DS . 'clientarea.tpl',
            'templateVariables' => [],
            'params' => $params,
        ];

    } catch (Exception $e) {

    }
}

function HostwindsReseller_default_ClientAreaCustomButtonArray($params)
{
    $module = HostwindsReseller_default_module::getModule($params['pid']);
    $moduleReturn = (array)HostwindsReseller_default_SimpleModuleFunction('ClientAreaCustomButtonArray');
    //$moduleReturn['Manage Service'] = 'manage';
    if (strpos($module->product->servertype, '_cpanel') !== false) {
        $moduleReturn['Login to cPanel'] = 'loginTocPanel';
        $moduleReturn['Login to Webmail'] = 'loginToWebmail';
    }
    return $moduleReturn;
}

function HostwindsReseller_default_manage($params)
{

    $submodulepage = isset($_GET['submodulepage']) ? $_GET['submodulepage'] : 'manageservice';
    try {
        $module = HostwindsReseller_default_module::getModule($params['pid']);
        $module->params = $params;
        $module->hosting = new HostwindsReseller_default_Hosting($params['serviceid']);
        $method = 'clientarea_' . $submodulepage;
        $vars = $module->$method($params);
        $vars['_LANG'] = $module->getLang();

        $submodule = substr(get_class($module), strlen('HostwindsReseller_default_'));
        $additionalFunctionsPath = dirname(__FILE__) . DS . 'modules' . DS . $submodule . DS . 'functions.php';
        if (file_exists($additionalFunctionsPath)) {
            include_once $additionalFunctionsPath;
        }

        return [
            'templatefile' => 'modules' . DS . $submodule . DS . 'templates' . DS . $submodulepage,
            'vars' => $vars,
        ];

    } catch (Exception $e) {

    }
}

function HostwindsReseller_default_serviceStatusSync($params)
{
    return HostwindsReseller_default_SimpleModuleCall('StatusSync', $params);
}

function HostwindsReseller_default_LoginLink($params)
{
    return HostwindsReseller_default_SimpleModuleFunction('LoginLink', $params);
}

function HostwindsReseller_default_AdminLink($params)
{
    try {
        $module = HostwindsReseller_default_module::getModule(0); // default
        $module->params = $params;
        $response = $module->testConnection();
        if ($response->isSuccess()) {
            return '<strong style="color:green">Connection OK</strong>';
        } else {
            return '<strong style="color:red">Error: ' . $response->getMessage() . '</strong>';
        }

    } catch (Exception $e) {
        return '<strong style="color:red">Connection Error: ' . $e->getMessage() . '</strong>';
    }
}

function HostwindsReseller_default_AdminCustomButtonArray()
{
    //return HostwindsReseller_default_SimpleModuleFunction('AdminCustomButtonArray');
    return [
        'Status Synchronization' => 'serviceStatusSync',
    ];
}

function HostwindsReseller_default_UsageUpdate($params)
{
    $result = HostwindsReseller_default_SimpleModuleFunction('UsageUpdate', $params);
    if ($result['success']) {
        $updateData = $result['data'];
        $updateData['lastupdate'] = date('Y-m-d H:i:s');
        foreach ($updateData as $k => $v) {
            $v = is_numeric($v) ? $v : '' . mysql_escape_quote_string($v) . '';
            $sets[] = $k . '=' . $v;
        }

        mysql_query_safe('UPDATE tblhosting SET ' . implode(',', $sets) . ' WHERE id = ' . (int)$params['serviceid']);
    }

}

function HostwindsReseller_default_AdminServicesTabFields($params)
{
    return HostwindsReseller_default_SimpleModuleFunction('AdminServicesTabFields', $params);
}

function HostwindsReseller_default_AdminServicesTabFieldsSave($params)
{
    return HostwindsReseller_default_SimpleModuleFunction('AdminServicesTabFieldsSave', $params);
}

function HostwindsReseller_default_SimpleModuleCall($method, $params)
{
    try {
        $module = HostwindsReseller_default_module::getModule($params['pid']);
        $module->params = $params;
        $module->hosting = new HostwindsReseller_default_Hosting($params['serviceid']);

        if ($method == 'CreateAccount') {
            $module->generateDefaultCustomField($params['pid']);
        }

        $response = $module->$method($params);
        if (is_string($response)) {
            return $response;
        } else {
            return $response->isSuccess() ? 'success' : $response->getMessage();
        }
    } catch (Exception $e) {
        return $e->getMessage();
    }
}

function HostwindsReseller_default_SimpleModuleFunction($method, array $params = [])
{
    try {
        $module = HostwindsReseller_default_module::getModule($params['pid']);
        $module->params = $params;
        $module->hosting = new HostwindsReseller_default_Hosting($params['serviceid']);
        $response = $module->$method($params);
        return $response;
    } catch (Exception $e) {

    }
}
