<?php
define('DS', DIRECTORY_SEPARATOR);
define('WHMCS_MAIN_DIR', ROOTDIR . DS . 'modules' . DS . 'addons');
define('ADDON_DIR',
    WHMCS_MAIN_DIR . DS . 'Hostwinds' . 'Reseller'); //Needs to be 2 string to avoid strepalce for generation
require ADDON_DIR . DS . 'classes' . DS . 'ServiceSync.php';

class HostwindsReseller_default_default extends HostwindsReseller_default_module
{
    public $defaultCustomField = [
        'hosting_id' => [
            'type' => 'text',
            'title' => 'Hosting ID In The Main WHMCS',
            'adminonly' => true,
        ],
    ];

    public function CreateAccount()
    {
        /*if ($this->hosting->getCustomField('hosting_id') && $this->hosting->hosting_details['domainstatus'] != 'Pending') {
            return 'Custom Field /hosting_id/ must be empty to run Create function';
        }*/

        $request = [
            'product_id' => $this->product->getConfig('target_product'),
            'billingcycle' => $this->hosting->hosting_details['billingcycle'],
            'domain' => $this->hosting->hosting_details['domain'],
            'serviceusername' => $this->hosting->hosting_details['username'],
            'servicepassword' => $this->params['password'],
        ];
        //if hosting has hosting id field filled then prevent create action in main
        if ($this->hosting->getCustomField('hosting_id')) {
            $request['preventCreateHosting'] = $this->hosting->getCustomField('hosting_id');
        }

        if ($this->product->type == 'server') {
            $ex_ns1 = explode('.', $this->hosting->hosting_details['ns1']);
            $ex_ns2 = explode('.', $this->hosting->hosting_details['ns2']);
            $ex_domain = explode('.', $this->hosting->hosting_details['domain']);

            $request['hostname'] = $this->hosting->hosting_details['domain'];
            $request['ns1prefix'] = implode('.', array_diff($ex_ns1, $ex_domain));
            $request['ns2prefix'] = implode('.', array_diff($ex_ns2, $ex_domain));
            $request['rootpw'] = $this->params['password'];
        }

        $configoptions = [];
        $prodConfig = $this->product->loadConfig();
        foreach ($prodConfig as $setting => $value) {
            if (substr($setting, 0, 7) == 'confop_') {
                $configoptions[substr($setting, 7)] = $value;
            }
        }
        foreach ($this->hosting->configurable_options as $name => $value) {
            $configoptions[$name] = $value;
        }

        if (!empty($configoptions)) {
            $request['configoptions'] = $configoptions;
        }

        $response = $this->callApi('CreateAccount', $request);
        if ($response->isSuccess()) {
            $this->hosting->setCustomField('hosting_id', $response->json['hosting_id']);

            $update = [];
            if (isset($response->json['username'])) {
                $update['username'] = $response->json['username'];
            }
            if (isset($response->json['password'])) {
                $update['password'] = encrypt($response->json['password']);
            }

            if (isset($response->json['dedicatedip'])) {
                $update['dedicatedip'] = $response->json['dedicatedip'];
            }

            if (isset($response->json['assignedips'])) {
                $update['assignedips'] = $response->json['assignedips'];
            }

            if (!empty($update)) {
                $this->hosting->updateDetails($update);
            }

            if ($response->isOrdered() && !$response->isProvisioned()) {
                $sleep = ($this->hosting->hosting_details['domainstatus'] != 'Active') ? 60 : 0;
                $this->StatusSync();
                $response->json['result'] = 0;
            }
        }

        return $response;
    }

    public function TerminateAccount()
    {
        $response = $this->callApi('TerminateAccount', [
            'hosting_id' => $this->hosting->getCustomField('hosting_id'),
        ]);
        if ($response->isSuccess()) {
            $this->hosting->setCustomField('hosting_id', '');
        }

        return $response;
    }

    public function SuspendAccount()
    {
        return $this->callApi('SuspendAccount', [
            'hosting_id' => $this->hosting->getCustomField('hosting_id'),
            'suspendreason' => 'ResellersSuspend',
        ]);
    }

    public function UnsuspendAccount()
    {
        return $this->callApi('UnsuspendAccount', [
            'hosting_id' => $this->hosting->getCustomField('hosting_id'),
        ]);
    }

    public function ChangePassword()
    {
        return $this->callApi('ChangePassword', [
            'hosting_id' => $this->hosting->getCustomField('hosting_id'),
            'servicepassword' => $this->params['password'],
        ]);
    }

    public function ChangePackage()
    {
        if (!$this->hosting->getCustomField('hosting_id')) {
            return 'Custom Field /hosting_id/ is empty';
        }

        $productResponse = $this->callApi('ServicesProduct', [
            'hosting_id' => $this->hosting->getCustomField('hosting_id'),
        ]);

        if ($productResponse->isSuccess()) {

            $request = [
                'hosting_id' => $this->hosting->getCustomField('hosting_id'),
                'serviceid' => $this->hosting->getCustomField('hosting_id'),
                'newproductbillingcycle' => $this->hosting->hosting_details['billingcycle'],
            ];

            if ($productResponse->json['product_id'] != $this->product->getConfig('target_product')) { // PRODUCT UPGRADE

                $request['type'] = 'product';
                $request['newproductid'] = $this->product->getConfig('target_product');

            } else { // CONFIGURABLE OPTIONS UPGRADE

                $request['type'] = 'configoptions';

                $configoptions = [];
                $prodConfig = $this->product->loadConfig();
                foreach ($prodConfig as $setting => $value) {
                    if (substr($setting, 0, 7) == 'confop_') {
                        $configoptions[substr($setting, 7)] = $value;
                    }
                }
                foreach ($this->hosting->configurable_options as $name => $value) {
                    $configoptions[$name] = $value;
                }

                if (!empty($configoptions)) {
                    $request['configoptions'] = $configoptions;
                }

            }

            $response = $this->callApi('ChangePackage', $request);

            if (isset($response->json['assignedips'])) {
                $update['assignedips'] = $response->json['assignedips'];
            }
            if (isset($response->json['dedicatedip'])) {
                $update['dedicatedip'] = $response->json['dedicatedip'];
            }

            if (!empty($update)) {
                $this->hosting->updateDetails($update);
            }

            return $response;

        } else {
            return $productResponse->getMessage();
        }
    }

    public function StatusSync($sleep = 0)
    {
        require_once '..' . DS . 'Hostwinds' . 'Reseller' . 'API' . DS . 'classes' . DS . 'class.Hostwinds' . 'Reseller_Hosting.php';
        require_once '..' . DS . 'Hostwinds' . 'Reseller' . 'API' . DS . 'helpers' . DS . 'WHMCS.php';


        if (!$this->hosting->getCustomField('hosting_id')) {
            return 'Custom Field /hosting_id/ is empty';
        }
        $response = $this->callApi('ServicesStatus', [
            'hosting_id' => $this->hosting->getCustomField('hosting_id'),
        ]);
        if ($response->isSuccess()) {

            $serviceSync = new ServiceSync();
            $serviceSync->serviceSync($this->hosting->id);

            $oldServiceStatus = $this->hosting->hosting_details['domainstatus'];
            $mainServiceStatus = $response->json['status'];

            //if mian and reseller's service statuses are different update reseller serivice
            if ($oldServiceStatus != $mainServiceStatus) {
                $update = [
                    'domainstatus' => $mainServiceStatus,
                ];

                $this->hosting->updateDetails($update);
                //if change from Pending to Active send Welcome Email


                if ($oldServiceStatus == 'Pending' && $mainServiceStatus == 'Active') {
                    $class = 'Hostwinds' . 'Reseller_Hosting';
                    $hosting = new $class($this->hosting->getCustomField('hosting_id'));
                    $hosting->sendWelcomeEmail();
                }
            }
        } else {
            return $response->getMessage();
        }

        return 'success';
    }

    public function AdminServicesTabFields()
    {

        if (!$this->hosting->getCustomField('hosting_id')) {
            return ['Status On The Main WHMCS' => '<strong style="color:red">No hosting_id. Call Create first!</strong>'];
        }

        $res = $this->callApi('ServicesStatus', [
            'hosting_id' => $this->hosting->getCustomField('hosting_id'),
        ]);
        if ($res->isSuccess()) {
            return ['Status On The Main WHMCS' => '<strong style="color:' . ($res->json['status'] == 'Active' ? 'green' : 'red') . '">' . $res->json['status'] . '</strong>'];
        } else {
            return ['Status On The Main WHMCS' => '<strong style="color:red">' . $res->getMessage() . '</strong>'];
        }
    }
}
